==> green-core-1.68.1.tgz: package/components/textarea/index.js <==
import {
  GdsTextarea
} from "../../chunks/chunk.OHXIVIJX.js";
import "../../chunks/chunk.VHN4JEZC.js";
import "../../chunks/chunk.VZTV63IQ.js";
import "../../chunks/chunk.VHLWBCJK.js";
import "../../chunks/chunk.HO2KZJXR.js";
import "../../chunks/chunk.7GC6JLT5.js";
import "../../chunks/chunk.2BJVQ5WE.js";
import "../../chunks/chunk.LC52PAHO.js";
import "../../chunks/chunk.S3FBHJYG.js";
import "../../chunks/chunk.H4QXCNY2.js";
import "../../chunks/chunk.IVRW42EY.js";
import "../../chunks/chunk.ALFDKEVN.js";
import "../../chunks/chunk.WJ2LHYQL.js";
import "../../chunks/chunk.GUAH7AIO.js";
import "../../chunks/chunk.CK2UGCPG.js";
import "../../chunks/chunk.EQ3Q4JI4.js";
import "../../chunks/chunk.3M4XRCEF.js";
import "../../chunks/chunk.2WQCB35E.js";
import "../../chunks/chunk.M5C2HLKD.js";
import "../../chunks/chunk.DINSYVIF.js";
import "../../chunks/chunk.JGTSJ4J6.js";
import "../../chunks/chunk.S3CXDAJ6.js";
import "../../chunks/chunk.TX64TTBN.js";
import "../../chunks/chunk.US7BP4IH.js";
import "../../chunks/chunk.VA6TUMR2.js";
import "../../chunks/chunk.WM7HBMMV.js";
import "../../chunks/chunk.TWXTKG4B.js";
import "../../chunks/chunk.76QWARGM.js";
import "../../chunks/chunk.NUUST5OZ.js";
import "../../chunks/chunk.JOVDFFXL.js";
import "../../chunks/chunk.TYGMNHNO.js";
import "../../chunks/chunk.JW27E2C3.js";
import "../../chunks/chunk.6QMJ7GQK.js";
import "../../chunks/chunk.YO24ZYAD.js";
import "../../chunks/chunk.TMEWQZER.js";
import "../../chunks/chunk.QK3R23GV.js";
import "../../chunks/chunk.B7ZOSVCQ.js";
import "../../chunks/chunk.SEHSDSX2.js";
export {
  GdsTextarea
};

==> green-core-1.68.2.tgz: package/components/textarea/index.js <==
import {
  GdsTextarea
} from "../../chunks/chunk.K37Q46SR.js";
import "../../chunks/chunk.VHN4JEZC.js";
import "../../chunks/chunk.VZTV63IQ.js";
import "../../chunks/chunk.VHLWBCJK.js";
import "../../chunks/chunk.HO2KZJXR.js";
import "../../chunks/chunk.7GC6JLT5.js";
import "../../chunks/chunk.2BJVQ5WE.js";
import "../../chunks/chunk.3E43CB7B.js";
import "../../chunks/chunk.S3FBHJYG.js";
import "../../chunks/chunk.H4QXCNY2.js";
import "../../chunks/chunk.IVRW42EY.js";
import "../../chunks/chunk.ALFDKEVN.js";
import "../../chunks/chunk.AEAXFPCN.js";
import "../../chunks/chunk.GUAH7AIO.js";
import "../../chunks/chunk.CK2UGCPG.js";
import "../../chunks/chunk.GWVFRI75.js";
import "../../chunks/chunk.3M4XRCEF.js";
import "../../chunks/chunk.STPU7PZQ.js";
import "../../chunks/chunk.M5C2HLKD.js";
import "../../chunks/chunk.WTJ56STD.js";
import "../../chunks/chunk.JGTSJ4J6.js";
import "../../chunks/chunk.3ZAUGUWX.js";
import "../../chunks/chunk.TX64TTBN.js";
import "../../chunks/chunk.V2WDTZ3V.js";
import "../../chunks/chunk.VA6TUMR2.js";
import "../../chunks/chunk.WM7HBMMV.js";
import "../../chunks/chunk.TWXTKG4B.js";
import "../../chunks/chunk.76QWARGM.js";
import "../../chunks/chunk.NUUST5OZ.js";
import "../../chunks/chunk.MSVSBAC6.js";
import "../../chunks/chunk.TYGMNHNO.js";
import "../../chunks/chunk.HEJU5WUE.js";
import "../../chunks/chunk.6QMJ7GQK.js";
import "../../chunks/chunk.YO24ZYAD.js";
import "../../chunks/chunk.TMEWQZER.js";
import "../../chunks/chunk.QK3R23GV.js";
import "../../chunks/chunk.B7ZOSVCQ.js";
import "../../chunks/chunk.SEHSDSX2.js";
export {
  GdsTextarea
};
